@@ -20,10 +20,10 @@ sub new {
 	my $invocant = shift();
 	my $class = ref($invocant) || $invocant;
 	$class = bless {
-		db_path => 'L:\FMCSA Projects\srcsafe.ini',
-		username => 'BPrudent',
-		password => 'BPrudent',
-		vss_base => '$/Development/',
+		db_path => undef,
+		username => "",
+		password => "",
+		vss_base => undef,
 		debug => 0,
 
 		_vssdb => undef
@@ -45,6 +45,21 @@ sub init {
 		}
 	}
 
+	if (!defined($self->{db_path}))
+	{
+		my $Registry;
+		require Win32::TieRegistry;
+		import Win32::TieRegistry ( Delimiter => "/", TiedRef => \$Registry );
+
+		# Work out the DB path from the registry
+		$self->{'db_path'} = $Registry->{"CUser/Software/Microsoft/SourceSafe/Current Database"};
+		Carp::croak ("No VSS DB path provided and none found in registry. If you have the VSS Shell installed, use the " .
+					 "'File->Open SourceSafe Database' menu option with the " .
+					 "'Open this database next time...' option to set a default") 
+			if (!defined($self->{'db_path'}));
+		$self->{'db_path'} .= "\\srcsafe.ini";
+	}
+
 	$self->{'_vssdb'} = Win32::OLE->new('SourceSafe');
 	$self->oleerr();
 
@@ -319,7 +334,7 @@ VSS - Visual Source Safe Class
 	my $item = $vss->checkout('src/main.c');
 	$item = $vss->checkin($item);
 
-	$vss->share_and_branch('fmcsa/cmvdbc.htm.xml', '$/Production/fmcsa/cmvdbc.htm.xml');
+	$vss->share_and_branch('cmvdbc.htm.xml', '$/Production/cmvdbc.htm.xml');
 
 =head1 WARNING
 
@@ -336,17 +351,15 @@ The following arguments can be passed to this module:
 =head2 db_path
 
 The path to your srcsafe.ini file. In some versions of VSS you may need to pass the
-name of the directory that contains the srcsafe.ini file. The default is what works
-on my computer.
+name of the directory that contains the srcsafe.ini file.
 
 =head2 username
 
-The username you use to log into VSS. The default is what works
-on my computer.
+The username you use to log into VSS.
 
 =head2 password
 
-The password you use to log into VSS. The default is my username.
+The password you use to log into VSS.
 
 =head2 vss_base
 
@@ -565,6 +578,11 @@ L<WIN32::OLE>
 L<http://msdn.microsoft.com/library/en-us/dnvss/html/vssauto.asp>
 L<http://msdn.microsoft.com/library/default.asp?url=/library/en-us/dnvss/html/msdn_vssole.asp>
 
+=head1 CREDITS
+
+Thanks to Shaun-lost-his-full-name-and-email-address for the update from Version 1.0.2 to Version 1.0.3. He removed the hardcoded defaults and instead
+searched the registry for the values that the shell uses via L<Win32::TieRegistry>. Very cool!
+
 =head1 AUTHOR
 
 BPrudent (Brandon Prudent)
